/**********************************************************************
 *     EPSCAN, an EPSON ES-1200 scanner driver     
 *     Adam P. Jenkins <ajenkins@cs.umass.edu>
 *     
 *     This program is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU General Public License
 *     as published by the Free Software Foundation; either version 2
 *     of the License, or (at your option) any later version.
 *     
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *     
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **********************************************************************/

#include <qlayout.h>

#include "ValSlider.h"

ValSlider::ValSlider(int minValue, int maxValue, int LineStep, int PageStep,
		     int val, QWidget *parent, const char *name)
: QWidget(parent, name)
{
  QBoxLayout *layout = new QBoxLayout(this, QBoxLayout::LeftToRight, 2);
  CHECK_PTR(layout);

  valDisplay = new QLabel("00000", this);
  CHECK_PTR(valDisplay);
  valDisplay->adjustSize();
  valDisplay->setMinimumSize(valDisplay->size());
  valDisplay->setNum(val);
  valDisplay->setFrameStyle(QFrame::Panel | QFrame::Sunken);

  layout->addWidget(valDisplay);
  
  slider = new QSlider(minValue, maxValue, LineStep, val,
			  QSlider::Horizontal, this);
  CHECK_PTR(slider);
  slider->setMinimumSize(50, valDisplay->height());
  connect(slider, SIGNAL(valueChanged(int)), SIGNAL(valueChanged(int)) );
  connect(slider, SIGNAL(valueChanged(int)),
	  valDisplay, SLOT(setNum(int)) );

  layout->addWidget(slider, 10);

  layout->activate();
}
  
